@@ -490,6 +490,7 @@ function dh_page_web_tv($params) {
 
         // Commentaire
         register_setting('dh-plugin-settings-group', 'dh_is_cmt_active');
+        register_setting('dh-plugin-settings-group', 'dh_is_nl_active');
 
         // Social
         register_setting('dh-plugin-settings-group', 'dh_fb_app_id_emag');
@@ -942,6 +943,13 @@ article.post-content h3{
                             <input type="checkbox" name="dh_is_cmt_active" value="1" <?php checked(1 == $dh_commentaire_is_active); ?>>
                         </td>
                     </tr>
+                    <tr valign="top">
+                        <th scope="row">Activer la newsletter</th>
+                        <td>
+                            <?php $dh_nl_is_active = get_option("dh_is_nl_active"); ?>
+                            <input type="checkbox" name="dh_is_nl_active" value="1" <?php checked(1 == $dh_nl_is_active); ?>>
+                        </td>
+                    </tr>
 
                     <tr valign="top">
                         <th scope="row">Nb de vidéo par page</th>
@@ -1388,4 +1396,4 @@ article.post-content h3{
     }
 
     add_action('admin_print_styles', 'admin_css', 11);
-    ?>
\ No newline at end of file
+    
\ No newline at end of file
